@@ -139,6 +139,26 @@ const PrintContext::PaperSizeMetrics PrintContext::PSM[MAX_PAPER_SIZE] =
     // A5 = 148mm x 210mm = 5.83 x 8.27 in.
     {
         (float)5.83, (float)8.27,   (float)5.58,  (float)7.645,   (float)0.125
+    },
+
+    // LEDGER = 11 x 17 in.
+    {
+        (float)11.00, (float)17.00,   (float)10.6,  (float)16.375,   (float)0.125
+    },
+
+    // SUPERB = 13 x 19 in.
+    {
+        (float)13.00, (float)19.00,   (float)12.6,  (float)18.375,   (float)0.125
+    },
+
+    // EXECUTIVE = 7.25 x 10.5 in.
+    {
+        (float)7.25, (float)10.5,   (float)6.75,  (float)9.875,   (float)0.125
+    },
+
+    // FLSA = 8.5 x 13 in.
+    {
+        (float)8.5, (float)13,   (float)8.00,  (float)12.375,   (float)0.125
     }
 #endif
 
@@ -685,30 +705,28 @@ BOOL PrintContext::PhotoTrayPresent
     }
     else
     {
-        return thePrinter->PhotoTrayPresent(bQueryPrinter);
+        return thePrinter->PhotoTrayPresent (bQueryPrinter);
     }
-} //PhotoTrayInstalled
+} //PhotoTrayPresent
 
-/*
- *  Removed because Malibu based printers donot have the sensor to
- *  report this correctly
- *
-BOOL PrintContext::PhotoTrayEngaged
+//! Return current status of PhotoTray - can be UNKNOWN, ENGAGED or DISENGAGED
+/*!
+******************************************************************************/
+
+PHOTOTRAY_STATE PrintContext::PhotoTrayEngaged
 (
     BOOL bQueryPrinter
 )
 {
     if (thePrinter == NULL)
     {
-        return FALSE;
+        return DISENGAGED;
     }
     else
     {
-        return thePrinter->PhotoTrayEngaged(bQueryPrinter);
+        return thePrinter->PhotoTrayEngaged (bQueryPrinter);
     }
 } //PhotoTrayEngaged
-*/
-
 
 //~PrintContext
 //! Destroy the print device context
@@ -1148,7 +1166,23 @@ DRIVER_ERROR PrintContext::setpixelsperrow
     // new value is legal
     InputWidth = InputPixelsPerRow;
     OutputWidth = OutputPixelsPerRow;
-return NO_ERROR;
+
+/*
+ *	Adjust OutputWidth to avoid fractional scaling.
+ */
+
+	int	iScaleFactor = (int) (((float) OutputWidth / (float) InputWidth) + 0.02);
+	int	iDiff = OutputWidth - InputWidth * iScaleFactor;
+	if (iDiff > 0 && iDiff < ((12 * (int) baseres) / 300))
+	{
+		OutputWidth = InputWidth * iScaleFactor;
+		if (OutputWidth > PageWidth)
+		{
+			OutputWidth = PageWidth;
+		}
+	}
+
+	return NO_ERROR;
 } //setpixelsperrow
 
 
