@@ -55,9 +55,10 @@ extern unsigned long ulMapVENICE_KCMY[ 9 * 9 * 9 ];
 extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 extern unsigned long ulMapVENICE_HB_KCMY[ 9 * 9 * 9 ];
 extern unsigned long ulMapVENICE_Binary_KCMY[ 9 * 9 * 9 ];
+extern unsigned long ulMapGRAY_K_6x6x1[9 * 9 * 9];
 
 
-VeniceMode1::VeniceMode1()
+VeniceMode1::VeniceMode1()    // Normal Color
 : PrintMode(ulMapVENICE_KCMY)
 // 600x600x1 K
 // 300x300x2 CMY
@@ -84,7 +85,7 @@ VeniceMode1::VeniceMode1()
     bFontCapable = FALSE;       // Venice can't do fonts and hifipe at same time
 }
 
-VeniceMode2::VeniceMode2()
+VeniceMode2::VeniceMode2()    // Photo
 : PrintMode(ulMapVENICE_HB_KCMY)
 // 600x600x1 K
 // 600x600x2 CMY
@@ -121,7 +122,7 @@ VeniceMode2::VeniceMode2()
      pmMediaType = MEDIA_PHOTO;
 }
 
-VeniceMode3::VeniceMode3()
+VeniceMode3::VeniceMode3()    // Draft Color
 : PrintMode(ulMapVENICE_Binary_KCMY)
 // 300x300x1 KCMY
 {
@@ -131,6 +132,25 @@ VeniceMode3::VeniceMode3()
     pmQuality = QUALITY_DRAFT;
 }
 
+VeniceMode4::VeniceMode4()    // Draft Gray K
+: GrayMode(ulMapVOLTAIRE_CCM_K)
+// 300x300x1 K
+{
+    theQuality = qualityDraft;
+    pmQuality = QUALITY_DRAFT;
+}
+
+#ifdef APDK_AUTODUPLEX
+VeniceMode5::VeniceMode5()    // Normal Gray K
+: GrayMode(ulMapGRAY_K_6x6x1)
+// 600x600x1 K
+{
+    BaseResX = BaseResY = 600;
+    ResolutionX[K]=ResolutionY[K]=600;
+    bFontCapable = FALSE;
+}
+#endif
+
 DJ8xx::DJ8xx(SystemServices* pSS,
                        int numfonts, BOOL proto)
     : Printer(pSS, numfonts, proto)
@@ -143,11 +163,16 @@ DJ8xx::DJ8xx(SystemServices* pSS,
     }
     else ePen=BOTH_PENS;    // matches default mode
 
-    pMode[GRAYMODE_INDEX]      = new GrayMode (ulMapVOLTAIRE_CCM_K);
-    pMode[DEFAULTMODE_INDEX]   = new VeniceMode1 ();
-    pMode[SPECIALMODE_INDEX]   = new VeniceMode2 ();
-    pMode[SPECIALMODE_INDEX+1] = new VeniceMode3 ();
-    ModeCount = 4;
+#ifdef APDK_AUTODUPLEX
+    pMode[GRAYMODE_INDEX]      = new VeniceMode5 ();   // Normal Gray K
+#else
+    pMode[GRAYMODE_INDEX]      = new GrayMode (ulMapVOLTAIRE_CCM_K);   // Normal Gray K
+#endif
+    pMode[DEFAULTMODE_INDEX]   = new VeniceMode1 ();   // Normal Color
+    pMode[SPECIALMODE_INDEX]   = new VeniceMode2 ();   // Photo
+    pMode[SPECIALMODE_INDEX+1] = new VeniceMode3 ();   // Draft Color
+    pMode[SPECIALMODE_INDEX+2] = new VeniceMode4 ();   // Draft Gray K
+    ModeCount = 5;
 
     CMYMap = ulMapVENICE_Binary_KCMY;
 
@@ -201,9 +226,9 @@ DRIVER_ERROR Header895::StartSend()
     err=Modes();            // Set media source, type, size and quality modes.
     ERRCHECK;
 
-    char uom[8];
+    char uom[10];
     sprintf(uom,"%c%c%c%d%c",ESC,'&','u',thePrintContext->EffectiveResolutionY(),'D');
-    err=thePrinter->Send((const BYTE*)uom, 7 );
+    err=thePrinter->Send((const BYTE*)uom, strlen (uom));
     ERRCHECK;
 
     if (!thePrinter->UseGUIMode(thePrintContext->CurrentMode))
@@ -277,7 +302,7 @@ DRIVER_ERROR DJ8xx::VerifyPenInfo()
         ERRCHECK;
 
         // give the printer some time to power up
-        if (pSS->BusyWait((DWORD)1000) == JOB_CANCELED)
+        if (pSS->BusyWait ((DWORD) 2500) == JOB_CANCELED)
         {
             return JOB_CANCELED;
         }
