@@ -71,9 +71,9 @@ DJ9xxVIP::DJ9xxVIP
 
     PCL3acceptsDriverware = IsPCL3DriverwareAvailable();
 
-    pMode[GRAYMODE_INDEX] = new GrayModeAladdin(ulMapVOLTAIRE_CCM_K,PCL3acceptsDriverware);
-    pMode[DEFAULTMODE_INDEX] = new AladdinMode();
-    pMode[SPECIALMODE_INDEX] = new AladdinCMYGrayMode();
+    pMode[GRAYMODE_INDEX] = new GrayModeAladdin(ulMapVOLTAIRE_CCM_K,PCL3acceptsDriverware);  // Grayscale K
+    pMode[DEFAULTMODE_INDEX] = new AladdinMode();           // Normal Color
+    pMode[SPECIALMODE_INDEX] = new AladdinCMYGrayMode();    // Normal Grayscale CMY
     ModeCount = 3;
 
 #ifdef APDK_AUTODUPLEX
@@ -84,9 +84,10 @@ DJ9xxVIP::DJ9xxVIP
  */
 
     bDuplexCapable = TRUE;
-    pMode[SPECIALMODE_INDEX+1] = new AladdinKGrayMode ();
-	pMode[SPECIALMODE_INDEX+2] = new Aladdin2400Mode ();
-    ModeCount = 5;
+    pMode[SPECIALMODE_INDEX+1] = new AladdinKGrayMode ();        // Normal Grayscale K
+    pMode[SPECIALMODE_INDEX+2] = new Aladdin2400Mode ();         // HiRes
+    pMode[SPECIALMODE_INDEX+3] = new AladdinDraftMode ();        // Draft Color
+    ModeCount = 6;
 #endif
 
 }
@@ -212,8 +213,24 @@ Aladdin2400Mode::Aladdin2400Mode () : PrintMode (NULL)
 	pmMediaType = MEDIA_PHOTO;
 	pmQuality = QUALITY_HIGHRES_PHOTO;
 } // Aladdin2400Mode
+
+AladdinDraftMode::AladdinDraftMode () : PrintMode (NULL)
+{
+	bFontCapable = FALSE;
+	bDuplexCapable = TRUE;
+#if defined(APDK_VIP_COLORFILTERING)
+    Config.bErnie = TRUE;
 #endif
 
+   Config.bColorImage = FALSE;
+
+	medium = mediaAuto;
+	theQuality = qualityDraft;
+	pmQuality = QUALITY_DRAFT;
+} // AladdinDraftMode
+
+#endif  // APDK_AUTODUPLEX
+
 BOOL DJ9xxVIP::UseGUIMode
 (
     PrintMode* pPrintMode
@@ -460,7 +477,48 @@ DRIVER_ERROR HeaderAladdin::Send()
     err = thePrinter->Send((const BYTE*)uom, 4 + digits );
     ERRCHECK;
     ////////////////////////////////////////////////////////////////////////////////////
+    float   fXOverSpray = 0.0;
+    float   fYOverSpray = 0.0;
+    float   fLeftOverSpray = 0.0;
+    float   fTopOverSpray  = 0.0;
 
+    if (thePrintContext->bDoFullBleed &&
+        thePrinter->FullBleedCapable (thePrintContext->thePaperSize,
+									  &fXOverSpray, &fYOverSpray,
+                                      &fLeftOverSpray, &fTopOverSpray))
+    {
+
+/*
+ *      To get the printer to do fullbleed printing, send the top and
+ *      left overspray commands. Overspray is needed to take care of
+ *      skew during paper pick. These values may be mech dependent.
+ *      Currently, supported only on PhotoSmart 100. Malibu supports
+ *      fullbleed printing also. The current values for overspray are
+ *      0.059 inch for top, bottom and left edges and 0.079 for right edge.
+ */
+
+        BYTE cBuf[4];
+        BYTE TopOverSpraySeq[]  = {0x1b, 0x2A, 0x6F, 0x35, 0x57, 0x0E, 0x02, 0x00};
+                                // "Esc*o5W 0E 02 00 00 00" Top edge overspray for full-bleed printing
+
+        BYTE LeftOverSpraySeq[] = {0x1b, 0x2A, 0x6F, 0x35, 0x57, 0x0E, 0x01, 0x00};
+                                // "Esc*o5W 0E 01 00 00 00" Left edge overspray for full-bleed printing
+
+        short topspray = (short)(fTopOverSpray * thePrintContext->EffectiveResolutionY() + 0.5);
+        cBuf[1] = topspray & 0xFF;
+        cBuf[0] = topspray >> 8;
+
+        err = thePrinter->Send ((const BYTE *) TopOverSpraySeq, sizeof (TopOverSpraySeq));
+        err = thePrinter->Send ((const BYTE *) cBuf, 2);
+
+        // set the left overspray value based on resolution and global constant for horizontal overspray
+        short leftspray = (short)(fLeftOverSpray * thePrintContext->EffectiveResolutionX() + 0.5);
+        cBuf[1] = leftspray & 0xFF;
+        cBuf[0] = leftspray >> 8;
+
+        err = thePrinter->Send ((const BYTE *) LeftOverSpraySeq, sizeof (LeftOverSpraySeq));
+        err = thePrinter->Send ((const BYTE *) cBuf, 2);
+    }
 
     // no need for compression command, it's in the CRD
 
@@ -512,50 +570,7 @@ DRIVER_ERROR HeaderAladdin::StartSend()
     {
         CAPy = thePrintContext->GUITopMargin();
     }
-    else
-    {
 
-/*
- *      To get the printer to do fullbleed printing, send the top and
- *      left overspray commands. Overspray is needed to take care of
- *      skew during paper pick. These values may be mech dependent.
- *      Currently, supported only on PhotoSmart 100. Malibu supports
- *      fullbleed printing also. The current values for overspray are
- *      0.059 inch for top, bottom and left edges and 0.079 for right edge.
- */
-
-        BYTE cBuf[4];
-        BYTE TopOverSpraySeq[]  = {0x1b, 0x2A, 0x6F, 0x35, 0x57, 0x0E, 0x02, 0x00};
-                                // "Esc*o5W 0E 02 00 00 00" Top edge overspray for full-bleed printing
-
-        BYTE LeftOverSpraySeq[] = {0x1b, 0x2A, 0x6F, 0x35, 0x57, 0x0E, 0x01, 0x00};
-                                // "Esc*o5W 0E 01 00 00 00" Left edge overspray for full-bleed printing
-//      short topspray = (short) ((long)((59 * thePrintMode->ResolutionX[K]) / 1000) &0x0000FFFF);
-//      But I found for best results, the value is 0x000E
-//        short topspray = 0x000E;
-
-        float   fXOverSpray = 0.0;
-        float   fYOverSpray = 0.0;
-        float   fLeftOverSpray = 0.0;
-        float   fTopOverSpray  = 0.0;
-        thePrinter->FullBleedCapable (thePrintContext->thePaperSize, &fXOverSpray, &fYOverSpray,
-                                      &fLeftOverSpray, &fTopOverSpray);
-
-        short topspray = (short)(fTopOverSpray * thePrintContext->EffectiveResolutionY() + 0.5);
-        cBuf[1] = topspray & 0xFF;
-        cBuf[0] = topspray >> 8;
-
-        err = thePrinter->Send ((const BYTE *) TopOverSpraySeq, sizeof (TopOverSpraySeq));
-        err = thePrinter->Send ((const BYTE *) cBuf, 2);
-
-        // set the left overspray value based on resolution and global constant for horizontal overspray
-        short leftspray = (short)(fLeftOverSpray * thePrintContext->EffectiveResolutionX() + 0.5);
-        cBuf[1] = leftspray & 0xFF;
-        cBuf[0] = leftspray >> 8;
-
-        err = thePrinter->Send ((const BYTE *) LeftOverSpraySeq, sizeof (LeftOverSpraySeq));
-        err = thePrinter->Send ((const BYTE *) cBuf, 2);
-    }
     return err;
 } //StartSend
 
@@ -667,7 +682,7 @@ DRIVER_ERROR DJ9xxVIP::VerifyPenInfo()
         ERRCHECK;
 
         // give the printer some time to power up
-        if (pSS->BusyWait((DWORD)1000) == JOB_CANCELED)
+        if (pSS->BusyWait ((DWORD) 2500) == JOB_CANCELED)
         {
             return JOB_CANCELED;
         }
@@ -1720,20 +1735,26 @@ BOOL DJ9xxVIP::PhotoTrayPresent
 } //PhotoTrayInstalled
 
 
-BOOL DJ9xxVIP::PhotoTrayEngaged
+PHOTOTRAY_STATE DJ9xxVIP::PhotoTrayEngaged
 (
     BOOL bQueryPrinter
 )
 {
+
+/*
+ *	When you add any new printer models to this class, make sure that the printer
+ *	has the phototray sensor and reports the phototray state correctly.
+ */
+
 #ifdef APDK_PROTO
     if (!IOMode.bDevID)
     {
-        return argPhotoTray;
+        return (PHOTOTRAY_STATE) argPhotoTray;
     }
 #endif
 
     // for phototray present and engaged == 9
-    return ((PhotoTrayStatus(bQueryPrinter) & 9) == 9);
+    return ((PHOTOTRAY_STATE) ((PhotoTrayStatus(bQueryPrinter) & 9) == 9));
 } //PhotoTrayEngaged
 
 
@@ -1772,7 +1793,7 @@ DRIVER_ERROR DJ9xxVIP::CheckInkLevel()
  *	Version 02 and onwards, report two additional bytes before pen info
  */
 
-    if (pSS->GetVIPVersion () < 3)
+    if (pSS->GetVIPVersion () < 2)
     {
 
 //      Aladdin style DeviceID
