@@ -634,19 +634,6 @@ public:
 }; //Header2xxx
 
 
-//ClassName
-/*
-******************************************************************************/
-class Header3320 : public Header
-{
-public:
-    Header3320 (Printer *p, PrintContext *pc);
-    DRIVER_ERROR Send ();
-protected:
-    DRIVER_ERROR EndJob ();
-    DRIVER_ERROR FormFeed ();
-    DRIVER_ERROR SendCAPy (unsigned int iAbsY);
-};
 //ClassName
 /*
 ******************************************************************************/
@@ -657,7 +644,6 @@ public:
     DRIVER_ERROR Send();
 };  //Header21xx
 
-
 //RasterSender
 //! Send rasters to the device
 /*!
