@@ -83,6 +83,15 @@
 #ifdef APDK_APOLLO2560
 #include "apollo2560.h"
 #endif
+#ifdef APDK_LJMONO
+#include "ljmono.h"
+#endif
+#ifdef APDK_LJCOLOR
+#include "ljcolor.h"
+#endif
+#ifdef APDK_PSCRIPT
+#include "pscript.h"
+#endif
 
 APDK_BEGIN_NAMESPACE
 
@@ -167,7 +176,6 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
         }
     }
 
-
     if (!match)
     {
     // The devID model string did not have a match for a known printer
@@ -420,13 +428,6 @@ DBG1("DR::InstantiateGeneral: device = ");
                 break;
 #endif
 
-#ifdef APDK_DJ3320
-            case (eDJ3320):
-                DBG1("DJ3320\n");
-                p = new DJ3320 (pSS);
-                break;
-#endif
-
 #ifdef APDK_APOLLO2XXX
             case(eAP2xxx):
                      DBG1("Apollo2xxx\n");
